pub enum BarcodeInstruction {
RequiresFNSKULabel,
CanUseOriginalBarcode,
MustProvideSellerSKU,
}Expand description
BarcodeInstruction : Labeling requirements for the item. For more information about FBA labeling requirements, see the Seller Central Help for your marketplace. Labeling requirements for the item. For more information about FBA labeling requirements, see the Seller Central Help for your marketplace.
Variants
RequiresFNSKULabel
CanUseOriginalBarcode
MustProvideSellerSKU